==> org-lsst-ccs-subsystem-refrig-gui-4.0.4-sources.jar: org/lsst/ccs/subsystem/refrig/ui/jas/CompressorPlugin.java <==
package org.lsst.ccs.subsystem.refrig.ui.jas;

import javax.swing.JPanel;
import org.lsst.ccs.bus.data.KeyValueData;
import org.lsst.ccs.bus.messages.EmbeddedObjectDeserializationException;
import org.lsst.ccs.bus.messages.StatusMessage;
import org.lsst.ccs.bus.messages.StatusSubsystemData;
import org.lsst.ccs.gconsole.annotations.Plugin;
import org.lsst.ccs.gconsole.base.Console;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.base.OptionalPage;
import org.lsst.ccs.messaging.StatusMessageListener;
import org.lsst.ccs.subsystem.refrig.constants.RefrigAgentProperties;
import org.lsst.ccs.subsystem.refrig.data.RefrigState;
import org.lsst.ccs.subsystem.refrig.ui.RefrigControlPanel;

/**
 * @author tonyj
 */
@Plugin(name = "Compressor Control Plugin", description = "Compressor Control Plugin")
public class CompressorPlugin extends ConsolePlugin {

    @Override
    public void initialize() {
        OptionalPage optPage = new CmprOptionalPage(RefrigAgentProperties.COMPRESSOR_TYPE, RefrigControl.class,
                                                    RefrigAgentProperties.HEX_TYPE);
        Console.getConsole().getOptionalPageService().add(optPage);
    }
    
    static class RefrigControl extends Control implements StatusMessageListener {

        private CommandSender cmdSender;
        private RefrigControlPanel ctrlPanel;
        
        @Override
        public void onStatusMessage(StatusMessage msg) {
            try {
                StatusSubsystemData sd = (StatusSubsystemData)msg;
                if (sd.getDataKey().equals(RefrigState.KEY)) {
                    updateControlPanel(((KeyValueData)sd.getSubsystemData()).getValue());
                }
            }
            catch (EmbeddedObjectDeserializationException x) {
            }
        }

        @Override
        public JPanel getControlPanel(CommandSender sndr) {
            cmdSender = sndr;
            return ctrlPanel = new RefrigControlPanel(sndr);
        }

        @Override
        public void initControlPanel() {
            updateControlPanel(cmdSender.sendCommand(null, "getSystemState"));
        }

        @Override
        public void updateControlPanel(Object obj) {
            ctrlPanel.updateControlPanel((RefrigState)obj);
        }

        @Override
        public void disableSystem() {
            ctrlPanel.disableSystem();
        }

        @Override
        public StatusMessageListener getListener() {
            return this;
        }

    }
    
}

==> org-lsst-ccs-subsystem-refrig-gui-4.0.5-sources.jar: org/lsst/ccs/subsystem/refrig/ui/jas/CompressorPlugin.java <==
package org.lsst.ccs.subsystem.refrig.ui.jas;

import javax.swing.JPanel;
import org.lsst.ccs.bus.data.KeyValueData;
import org.lsst.ccs.bus.messages.EmbeddedObjectDeserializationException;
import org.lsst.ccs.bus.messages.StatusMessage;
import org.lsst.ccs.bus.messages.StatusSubsystemData;
import org.lsst.ccs.gconsole.annotations.Plugin;
import org.lsst.ccs.gconsole.base.Console;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.services.optpage.OptionalPage;
import org.lsst.ccs.messaging.StatusMessageListener;
import org.lsst.ccs.subsystem.refrig.constants.RefrigAgentProperties;
import org.lsst.ccs.subsystem.refrig.data.RefrigState;
import org.lsst.ccs.subsystem.refrig.ui.RefrigControlPanel;

/**
 * @author tonyj
 */
@Plugin(name = "Compressor Control Plugin", description = "Compressor Control Plugin")
public class CompressorPlugin extends ConsolePlugin {

    @Override
    public void initialize() {
        OptionalPage optPage = new CmprOptionalPage(RefrigAgentProperties.COMPRESSOR_TYPE, RefrigControl.class,
                                                    RefrigAgentProperties.HEX_TYPE);
        Console.getConsole().getOptionalPageService().add(optPage);
    }
    
    static class RefrigControl extends Control implements StatusMessageListener {

        private CommandSender cmdSender;
        private RefrigControlPanel ctrlPanel;
        
        @Override
        public void onStatusMessage(StatusMessage msg) {
            try {
                StatusSubsystemData sd = (StatusSubsystemData)msg;
                if (sd.getDataKey().equals(RefrigState.KEY)) {
                    updateControlPanel(((KeyValueData)sd.getSubsystemData()).getValue());
                }
            }
            catch (EmbeddedObjectDeserializationException x) {
            }
        }

        @Override
        public JPanel getControlPanel(CommandSender sndr) {
            cmdSender = sndr;
            return ctrlPanel = new RefrigControlPanel(sndr);
        }

        @Override
        public void initControlPanel() {
            updateControlPanel(cmdSender.sendCommand(null, "getSystemState"));
        }

        @Override
        public void updateControlPanel(Object obj) {
            ctrlPanel.updateControlPanel((RefrigState)obj);
        }

        @Override
        public void disableSystem() {
            ctrlPanel.disableSystem();
        }

        @Override
        public StatusMessageListener getListener() {
            return this;
        }

    }
    
}
